@@ -1,11 +1,9 @@
 import time
 import board
-import busio
 import adafruit_ahtx0
 
-# Create library object using our Bus I2C port
-i2c = busio.I2C(board.SCL, board.SDA)
-sensor = adafruit_ahtx0.AHTx0(i2c)
+# Create the sensor object using I2C
+sensor = adafruit_ahtx0.AHTx0(board.I2C())
 
 while True:
     print("\nTemperature: %0.1f C" % sensor.temperature)
